@@ -1,26 +1,10 @@
-/* -------------------------------------------------------------
-   From KDE Tuberling
-   mailto:e.bischoff@noos.fr
- ------------------------------------------------------------- */
- /*
- * Copyright (C) 2001 Eric Bischoff <e.bischoff@noos.fr>
-   2004-2007 Anne-Marie Mahfouf <annma@kde.org>
-
-    This program is free software; you can redistribute it and/or
-    modify it under the terms of the GNU General Public
-    License as published by the Free Software Foundation; either
-    version 2 of the License, or (at your option) any later version.
-
-    This program is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-    GNU General Public License for more details.
-
-    You should have received a copy of the GNU General Public License
-    along with this program; if not, write to the Free Software
-    Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
- */
+/*
+    SPDX-FileCopyrightText: KDE Tuberling <e.bischoff@noos.fr>
+    SPDX-FileCopyrightText: 2001 Eric Bischoff <e.bischoff@noos.fr>
+    SPDX-FileCopyrightText: 2004-2007 Anne-Marie Mahfouf <annma@kde.org>
 
+    SPDX-License-Identifier: GPL-2.0-or-later
+*/
 
 #ifndef _SOUNDFACTORY_H_
 #define _SOUNDFACTORY_H_
@@ -51,7 +35,7 @@ class SoundFactory : public QObject
 public:
 
     explicit SoundFactory(KLettres *parent, const QString &name);
-    ~SoundFactory();
+    ~SoundFactory() override;
 
     ///Call the main instance of the program
     KLettres *klettres;
